AsyncCubit<T> class abstract

AsyncCubit is a cubit that loads data from some async source (eg. network, database).

It emits AsyncValue which can be in one of 3 states:

It is a base class for FutureCubit and StreamCubit.

Implementers

Constructors

AsyncCubit({AsyncValue<T>? initialState})
AsyncCubit is a cubit that loads data from some async source (eg. network, database).

Properties

debugKey String
Debug key for this cubit. Used for logging purposes.
no setter
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state AsyncValue<T>
The current state.
no setterinherited
stream Stream<AsyncValue<T>>
The current stream of states.
no setterinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
emit(AsyncValue<T> state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
emitMergeWithPrevious(AsyncValue<T> value) → void
Merge current state with the new one.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<AsyncValue<T>> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
toString() String
A string representation of this object.
inherited
updateData(T data) → void
Updates the AsyncCubit with the provided data. This method can be used to emit new data from the AsyncCubit without making call using load/refresh methods.

Operators

operator ==(Object other) bool
The equality operator.
inherited